# About this folder

Each **input** folder comprises a complete set of test data for one or more tests. Likewise, each **output** folder comprises a complete set of expected test results.

Each **test.config** file comprises a *trestle task* configuration employed by one or more tests.
